<?php

namespace Luticate\Auth\Controller;

use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticatePermissionsUsersBusiness;
use Luticate\Auth\DBO\LuticatePermissionsUsersDbo;

class LuticatePermissionsUsersController extends LuController {
    protected function getBusiness()
    {
        return new LuticatePermissionsUsersBusiness();
    }

    /**
     * Get all permissions for a user
     * @param $user_id int The user id
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @return \Luticate\Utils\LuMultipleDbo
     */
    public function getAllByUser($user_id, $page = 0, $perPage = PHP_INT_MAX)
    {
        return LuticatePermissionsUsersBusiness::getAllByUser($user_id, $page, $perPage);
    }

    /**
     * Get a permission for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @return \Luticate\Utils\LuDbo
     */
    public function get($user_id, $permission_name)
    {
        return LuticatePermissionsUsersBusiness::get($user_id, $permission_name);
    }

    /**
     * Add a permission for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @param $permission_value bool The permission value
     * @return bool
     */
    public function add($user_id, $permission_name, $permission_value)
    {
        return LuticatePermissionsUsersBusiness::add($user_id, $permission_name, $permission_value);
    }

    /**
     * Delete a permission for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @return bool
     */
    public function del($user_id, $permission_name)
    {
        return LuticatePermissionsUsersBusiness::del($user_id, $permission_name);
    }

    /**
     * Edit the permission value for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @param $permission_value bool The permission value
     * @return bool
     */
    public function edit($user_id, $permission_name, $permission_value)
    {
        return LuticatePermissionsUsersBusiness::edit($user_id, $permission_name, $permission_value);
    }
}